@@ -318,7 +318,6 @@ def gcs_del_storage_folder(bucket_id, folder=None, blob_name=None, storage_clien
             logging.error(str(err.message))
 
 
-
 def azure_get_credentials(**kwargs):
     """ infers and/or updates defaults for Azure SQL and Azure storage account
     defaults comes from credentials.json filepath set as environment 'AZURE_CREDENTIALS'
@@ -338,43 +337,45 @@ def azure_get_credentials(**kwargs):
     {dict} - credential dictionary
 
     """
-    default_credpath =  os.environ.get('AZURE_CREDENTIALS')
-    
+    default_credpath = os.environ.get('AZURE_CREDENTIALS')
+
     if default_credpath:
         with open(default_credpath, 'r') as file:
             credentials = json.load(file)
     else:
-        logging.warning('default credentials path does not exit, no defaults set for tableau server authentication')
+        logging.warning(
+            'default credentials path does not exit, no defaults set for tableau server authentication')
         credentials = {}
-    
+
     if 'account_name' in kwargs:
         credentials['account_name'] = kwargs['account_name']
-    
+
     if 'container_name' in kwargs:
         credentials['container_name'] = kwargs['container_name']
 
     if 'account_key' in kwargs:
         credentials['account_key'] = kwargs['account_key']
 
-
     if 'server' in kwargs:
         credentials['server'] = kwargs['server']
-        
+
     if 'username' in kwargs:
         credentials['username'] = kwargs['username']
-        
+
     if 'password' in kwargs:
         credentials['password'] = kwargs['password']
-    
+
     if 'database' in kwargs:
         credentials['database'] = kwargs['database']
-        
+
     return credentials
 
-def download_blob_azure_storage(blob_url, account_key=None, filepath=None, output_option='FILE', delete_blob=False):
-    """ downloads azure blob to FILE, io.BytesIO, STRING, JSON, google CREDENTIAL objects type
+# updated name
 
 
+def azure_storage_download_blob(blob_url, account_key=None, filepath=None, output_option='FILE', delete_blob=False):
+    """ downloads azure blob to FILE, io.BytesIO, STRING, JSON STRING type
+
     Arguments:
         blob_url {str} -- azure storage blob url e.g https://account_name.blob.core.windows.net/container_name/blob_name
         account_key {str} -- authentication method for azure storage
@@ -390,18 +391,16 @@ def download_blob_azure_storage(blob_url, account_key=None, filepath=None, outpu
         {STRING : unicode string}
         {IO : io.BytesIO}
         {URL: downloadable link}
-        {CREDENTIALS: google.oauth2.service_account.Credentials}
         {JSON: DICT}
-        {FILE: filepath} 
+        {FILE: filepath}
+
     """
     from io import BytesIO
-    from google.oauth2.service_account import Credentials
-
 
     account_name, container_name, blob_name = __parse_storage_url(blob_url)
     if not account_key:
-        account_key = azure_get_credentials().get('account_key') # dependency
-        
+        account_key = azure_get_credentials().get('account_key')  # dependency
+
     service = BlockBlobService(
         account_name=account_name, account_key=account_key)
     blob = service.get_blob_to_bytes(container_name, blob_name)
@@ -412,25 +411,22 @@ def download_blob_azure_storage(blob_url, account_key=None, filepath=None, outpu
 
     elif output_option == 'STRING':
         output = blob.content.decode()
-    
+
     elif output_option == 'JSON':
         output = json.loads(blob.content.decode())
-    
-    elif output_option == 'CREDENTIALS':
-        output = Credentials.from_service_account_info(json.loads(blob.content.decode()))
-    
+
     elif output_option == 'URL':
         from datetime import datetime, timedelta
         from azure.storage.blob import BlobPermissions
         from urllib.parse import quote
 
         sas_token = service.generate_blob_shared_access_signature(
-            container_name=container_name
-            ,blob_name=blob_name
-            ,permission=BlobPermissions(read=True),
+            container_name=container_name, blob_name=blob_name, permission=BlobPermissions(
+                read=True),
             expiry=datetime.utcnow() + timedelta(weeks=1)
         )
-        output = service.make_blob_url(container_name, quote(blob_name),sas_token=sas_token)
+        output = service.make_blob_url(
+            container_name, quote(blob_name), sas_token=sas_token)
 
     else:
         if not filepath:
@@ -438,13 +434,14 @@ def download_blob_azure_storage(blob_url, account_key=None, filepath=None, outpu
         with open(filepath, mode='wb') as file:
             file.write(blob.content)
         output = filepath
-    
+
     if delete_blob:
         service.delete_blob(container_name, blob_name)
 
     return output
 
-def upload_blob_azure_storage(content, blob_name=None, **credentials):
+
+def azure_storage_upload_blob(content, blob_name=None, **credentials):
     """Uploads content to Azure Storage
 
     Arguments:
@@ -459,35 +456,38 @@ def upload_blob_azure_storage(content, blob_name=None, **credentials):
     """
     import io
     from datetime import datetime
-    credentials = azure_get_credentials(**credentials) #dependency
-    
+    credentials = azure_get_credentials(**credentials)  # dependency
+
     account_name = credentials.get('account_name')
     container_name = credentials.get('container_name')
     account_key = credentials.get('account_key')
-    
+
     service = BlockBlobService(
         account_name=account_name, account_key=account_key)
-    
+
     if not blob_name:
         if os.path.isfile(content):
-            blob_name= os.path.basename(content)
-            service.create_blob_from_path(container_name,blob_name,content)
-            return __make_storage_url(account_name,container_name,blob_name)
+            blob_name = os.path.basename(content)
+            service.create_blob_from_path(container_name, blob_name, content)
+            return __make_storage_url(account_name, container_name, blob_name)
         else:
-            blob_name = 'unname_blob_uploaded_at' + datetime.now().isoformat().replace('-','_').replace(':','_')[:19]
+            blob_name = 'unname_blob_uploaded_at' + datetime.now().isoformat().replace('-',
+                                                                                       '_').replace(':', '_')[:19]
 
-    if isinstance(content,io.BytesIO):
-        service.create_blob_from_stream(container_name,blob_name,content)   
-    elif isinstance(content,bytes):
-        service.create_blob_from_bytes(container_name,blob_name,content)
+    if isinstance(content, io.BytesIO):
+        service.create_blob_from_stream(container_name, blob_name, content)
+    elif isinstance(content, bytes):
+        service.create_blob_from_bytes(container_name, blob_name, content)
     else:
-        service.create_blob_from_text(container_name,blob_name,content)
+        service.create_blob_from_text(container_name, blob_name, content)
     return __make_storage_url(account_name, container_name, blob_name)
 
+
 def __parse_storage_url(blob_url):
     account_name, container_name, blob_name = blob_url[8:].split('/')
     account_name = account_name.split('.')[0]
     return account_name, container_name, blob_name
 
-def __make_storage_url(account_name,container_name,blob_name):
+
+def __make_storage_url(account_name, container_name, blob_name):
     return f'https://{account_name}.blob.core.windows.net/{container_name}/{blob_name}'
